| mGS | R Documentation |
This is an internal function which uses a R code to calculate an orthogonalization of a matrix. This function is used in the power method allowing to compute an eigendecomposition of a symmetric square.
mGS(A)
A |
Matrix in vector form. |
This function returns a matrix which columns are the eigenvectors
wp |
Eigevectors matrix. |
A <- matrix(rnorm(6,0,1), ncol=2)
res <- mGS(A)
t(res)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.